import { defineStore } from 'pinia'
import { ref, computed } from 'vue'

export interface Job {
  id: string
  title: string
  department: string
  location: string
  description: string
  status: 'active' | 'paused' | 'draft'
  pendingResumes: number
  passedResumes: number
  aiCriteria: {
    education: { condition: string; value: string; weight: number }
    experience: { condition: string; value: string; weight: number }
    skills: { condition: string; value: string; weight: number }
    language: { condition: string; value: string; weight: number }
  }
  createdAt: Date
  updatedAt: Date
}

export interface Candidate {
  id: string
  name: string
  jobId: string
  jobTitle: string
  matchScore: number
  status: 'pending' | 'passed' | 'rejected' | 'interviewed'
  highlights: string[]
  concerns: string[]
  summary: string
  resumeText: string
  education: string
  experience: string
  skills: string[]
  submittedAt: Date
  reviewedAt?: Date
}

export interface Interview {
  id: string
  title: string
  description: string
  questions: string[]
  duration: number
  createdAt: Date
}

export const useJobStore = defineStore('job', () => {
  // 状态
  const jobs = ref<Job[]>([])
  const candidates = ref<Candidate[]>([])
  const interviews = ref<Interview[]>([])
  const isModalOpen = ref(false)
  const isLoading = ref(false)
  const currentJob = ref<Job | null>(null)
  const currentCandidate = ref<Candidate | null>(null)

  // 计算属性
  const activeJobs = computed(() => 
    jobs.value.filter(job => job.status === 'active')
  )

  const totalPendingResumes = computed(() =>
    jobs.value.reduce((sum, job) => sum + job.pendingResumes, 0)
  )

  const totalCandidates = computed(() => candidates.value.length)

  const pendingCandidates = computed(() =>
    candidates.value.filter(candidate => candidate.status === 'pending')
  )

  const passedCandidates = computed(() =>
    candidates.value.filter(candidate => candidate.status === 'passed')
  )

  const rejectedCandidates = computed(() =>
    candidates.value.filter(candidate => candidate.status === 'rejected')
  )

  const interviewedCandidates = computed(() =>
    candidates.value.filter(candidate => candidate.status === 'interviewed')
  )

  const getCandidatesByJob = computed(() => (jobId: string) =>
    candidates.value.filter(candidate => candidate.jobId === jobId)
  )

  const getJobById = computed(() => (jobId: string) =>
    jobs.value.find(job => job.id === jobId)
  )

  // 统计数据
  const dashboardStats = computed(() => ({
    totalJobs: jobs.value.length,
    activeJobs: activeJobs.value.length,
    totalCandidates: totalCandidates.value,
    pendingCandidates: pendingCandidates.value.length,
    passedCandidates: passedCandidates.value.length,
    rejectedCandidates: rejectedCandidates.value.length,
    interviewedCandidates: interviewedCandidates.value.length,
    averageMatchScore: candidates.value.length > 0 
      ? Math.round(candidates.value.reduce((sum, c) => sum + c.matchScore, 0) / candidates.value.length)
      : 0,
    passRate: candidates.value.length > 0 
      ? Math.round((passedCandidates.value.length / candidates.value.length) * 100)
      : 0
  }))

  // 选项数据方法
  const fetchDepartments = async (): Promise<string[]> => {
    return ['技术部', '产品部', '设计部', '市场部']
  }
  
  const fetchLocations = async (): Promise<string[]> => {
    return ['北京', '上海', '广州', '深圳']
  }
  
  const fetchEducationOptions = async (): Promise<string[]> => {
    return ['不限', '高中', '专科', '本科', '硕士', '博士']
  }
  
  const fetchExperienceOptions = async (): Promise<string[]> => {
    return ['不限', '1年', '2年', '3年', '5年']
  }
  
  const fetchLanguageOptions = async (): Promise<string[]> => {
    return ['无要求', '英语四级', '英语六级']
  }

  // 动作
  const initializeData = () => {
    // 初始化数据...
  }

  const addJob = (jobData: Omit<Job, 'id' | 'createdAt' | 'updatedAt'>) => {
    const newJob: Job = {
      ...jobData,
      id: Date.now().toString(),
      createdAt: new Date(),
      updatedAt: new Date()
    }
    jobs.value.push(newJob)
  }

  const createJob = async (jobData: Omit<Job, 'id' | 'status' | 'pendingResumes' | 'passedResumes'>): Promise<void> => {
    const newJob: Job = {
      ...jobData,
      id: Date.now().toString(),
      status: 'active',
      pendingResumes: 0,
      passedResumes: 0,
      createdAt: new Date(),
      updatedAt: new Date()
    }
    jobs.value.push(newJob)
  }

  const updateJob = (jobId: string, updates: Partial<Job>) => {
    const index = jobs.value.findIndex(job => job.id === jobId)
    if (index !== -1) {
      jobs.value[index] = {
        ...jobs.value[index],
        ...updates,
        updatedAt: new Date()
      }
    }
  }

  const triggerScreening = async (jobId: string) => {
    const job = jobs.value.find(j => j.id === jobId)
    if (!job) return

    isLoading.value = true
    
    // 模拟AI筛选过程
    await new Promise(resolve => setTimeout(resolve, 2000))
    
    // 更新简历数量
    job.pendingResumes = 0
    job.passedResumes += Math.floor(Math.random() * 3) + 1
    job.updatedAt = new Date()
    
    isLoading.value = false
  }

  const updateCandidateStatus = (candidateId: string, status: Candidate['status']) => {
    const candidate = candidates.value.find(c => c.id === candidateId)
    if (candidate) {
      candidate.status = status
      candidate.reviewedAt = new Date()
    }
  }

  const batchScreenCandidates = async (candidateIds: string[]) => {
    isLoading.value = true
    
    // 模拟批量筛选
    await new Promise(resolve => setTimeout(resolve, 1500))
    
    candidateIds.forEach(id => {
      const candidate = candidates.value.find(c => c.id === id)
      if (candidate && candidate.status === 'pending') {
        // 根据匹配度自动判断
        candidate.status = candidate.matchScore >= 75 ? 'passed' : 'rejected'
        candidate.reviewedAt = new Date()
      }
    })
    
    isLoading.value = false
  }

  const openModal = () => {
    isModalOpen.value = true
  }

  const closeModal = () => {
    isModalOpen.value = false
    currentJob.value = null
  }

  const setCurrentJob = (job: Job | null) => {
    currentJob.value = job
  }

  const setCurrentCandidate = (candidate: Candidate | null) => {
    currentCandidate.value = candidate
  }

  const addInterview = (interviewData: Omit<Interview, 'id' | 'createdAt'>) => {
    const newInterview: Interview = {
      ...interviewData,
      id: Date.now().toString(),
      createdAt: new Date()
    }
    interviews.value.push(newInterview)
  }

  return {
    // 状态
    jobs,
    candidates,
    interviews,
    isModalOpen,
    isLoading,
    currentJob,
    currentCandidate,
    
    // 计算属性
    activeJobs,
    totalPendingResumes,
    totalCandidates,
    pendingCandidates,
    passedCandidates,
    rejectedCandidates,
    interviewedCandidates,
    getCandidatesByJob,
    getJobById,
    dashboardStats,
    
    // 动作
    initializeData,
    addJob,
    createJob,
    updateJob,
    triggerScreening,
    updateCandidateStatus,
    batchScreenCandidates,
    openModal,
    closeModal,
    setCurrentJob,
    setCurrentCandidate,
    addInterview,
    fetchDepartments,
    fetchLocations,
    fetchEducationOptions,
    fetchExperienceOptions,
    fetchLanguageOptions
  }
})